part of masamune.flutter;

/// BuildContext extension methods.
extension BuildContextExtension on BuildContext {
  /// Outputs the theme related to the context.
  ThemeData get theme => Theme.of(this);

  /// Get the Navigator related to context.
  NavigatorState get navigator => Navigator.of(this);

  /// Get the Root navigator related to context.
  NavigatorState get rootNavigator => Navigator.of(this, rootNavigator: true);

  /// Get the Flavor.
  String get flavor => FlavorScope.of(this)?.flavor;

  /// Get the data passed to the page.
  IDataDocument get data =>
      (ModalRoute.of(this)?.settings?.arguments as IDataDocument) ??
      TemporaryDocument();

  /// Get the media qury related to context
  MediaQueryData get mediaQuery => MediaQuery.of(this);

  /// Releases focus such as text field.
  void unfocus() {
    FocusScope.of(this).requestFocus(FocusNode());
  }
}

/// MediaQuery extension methods.
extension MediaQueryExtension on MediaQueryData {
  /// Calculate the size when dividing the horizontal length.
  ///
  /// Enter the actual number of elements in [count]
  /// and the maximum number to place horizontally in [maxHorizontalCount].
  ///
  /// [count]:　Element count.
  /// [maxHorizontalCount]: Maximum number of horizontal elements.
  double divisionWidth(int count, {int maxHorizontalCount = 5}) {
    if (count < 1) count = 1;
    if (maxHorizontalCount < 1) maxHorizontalCount = 1;
    double width = this.size.width;
    return (width / count).limitLow(width / maxHorizontalCount);
  }

  /// Calculate the size when dividing the vertical length.
  ///
  /// Enter the actual number of elements in [count]
  /// and the maximum number to place vertically in [maxVerticalCount].
  ///
  /// [count]:　Element count.
  /// [maxVerticalCount]: Maximum number of vertical elements.
  double divisionHeight(int count, {int maxVerticalCount = 5}) {
    if (count < 1) count = 1;
    if (maxVerticalCount < 1) maxVerticalCount = 1;
    double height = this.size.height;
    return (height / count).limitLow(height / maxVerticalCount);
  }
}
